@@ -58,4 +58,13 @@ class InvalidToken(Error):
     Args:
         Error (_type_): Base Error
     """
-    pass
\ No newline at end of file
+    pass
+
+class ItemNotFound(Error):
+    """Rasied when the item within the Marketplace is not found. This is used in Kumiko's Economy system. This should only be raised when the item within the database is not found.
+
+    Args:
+        Error (_type_): Base Error
+    """
+    pass
+
